=======
History
=======

2020.10 (2020-10-27)
--------------------

* Adding option to exclude simulation IDs 
* Allowing empty sweep ID

2020.09 (2020-09-02)
--------------------

* Incorporating sweep_id into SequentialNamer (thanks to danielphili)

2020.02 (2020-02-17)
--------------------

* Fixing bug with default sweep_id on Windows (thanks to danielphili)
* Unicode support for PythonFormatTemplate

2019.02.3 (2019-02-20)
----------------------

* Adding SetNamer naming

2019.02.2 (2019-02-18)
----------------------

* Adding process limit for subprocess dispatching
* Adding RandomSweep sweep type
* Adding HashNamer naming
* Clarifying version dependencies
* More examples

2019.02 (2019-02-07)
--------------------

* Separating sweep logic into a separate module
* Adding FilteredCartesianSweep sweep type
* Numerous documentation changes, including many more examples

2019.01 (2019-01-21)
--------------------

* First release on PyPI
